@@ -100,7 +100,7 @@ class BaseRemoteTree:
 
     CACHE_MODE = None
     SHARED_MODE_MAP = {None: (None, None), "group": (None, None)}
-    CHECKSUM_DIR_SUFFIX = ".dir"
+    PARAM_CHECKSUM = None
 
     state = StateNoop()
 
@@ -119,6 +119,7 @@ class BaseRemoteTree:
             or self.HASH_JOBS
         )
         self.verify = config.get("verify", self.DEFAULT_VERIFY)
+        self.path_info = None
 
     @classmethod
     def get_missing_deps(cls):
@@ -184,7 +185,8 @@ class BaseRemoteTree:
 
     def open(self, path_info, mode="r", encoding=None):
         if hasattr(self, "_generate_download_url"):
-            get_url = partial(self._generate_download_url, path_info)
+            func = self._generate_download_url  # noqa,pylint:disable=no-member
+            get_url = partial(func, path_info)
             return open_url(get_url, mode=mode, encoding=encoding)
 
         raise RemoteActionNotImplemented("open", self.scheme)
@@ -192,6 +194,8 @@ class BaseRemoteTree:
     def exists(self, path_info):
         raise NotImplementedError
 
+    # pylint: disable=unused-argument
+
     def isdir(self, path_info):
         """Optional: Overwrite only if the remote has a way to distinguish
         between a directory and a file.
@@ -209,7 +213,12 @@ class BaseRemoteTree:
         return False  # We can't be sure by default
 
     def walk_files(self, path_info, **kwargs):
-        """Return a generator with `PathInfo`s to all the files"""
+        """Return a generator with `PathInfo`s to all the files.
+
+        Optional kwargs:
+            prefix (bool): If true `path_info` will be treated as a prefix
+                rather than directory path.
+        """
         raise NotImplementedError
 
     def is_empty(self, path_info):
@@ -250,6 +259,8 @@ class BaseRemoteTree:
     def is_protected(self, path_info):
         return False
 
+    # pylint: enable=unused-argument
+
     @staticmethod
     def unprotect(path_info):
         pass
@@ -270,10 +281,10 @@ class BaseRemoteTree:
             return None
 
         if tree == self:
+            # pylint: disable=assignment-from-none
             hash_ = self.state.get(path_info)
         else:
             hash_ = None
-
         # If we have dir hash in state db, but dir cache file is lost,
         # then we need to recollect the dir via .get_dir_hash() call below,
         # see https://github.com/iterative/dvc/issues/2219 for context
@@ -323,7 +334,8 @@ class BaseRemoteTree:
             self.PARAM_CHECKSUM: self.get_hash(path_info, tree=tree, **kwargs)
         }
 
-    def _calculate_hashes(self, file_infos, tree):
+    @staticmethod
+    def _calculate_hashes(file_infos, tree):
         file_infos = list(file_infos)
         with Tqdm(
             total=len(file_infos),
@@ -331,7 +343,7 @@ class BaseRemoteTree:
             desc="Computing file/dir hashes (only done once)",
         ) as pbar:
             worker = pbar.wrap_fn(tree.get_file_hash)
-            with ThreadPoolExecutor(max_workers=self.hash_jobs) as executor:
+            with ThreadPoolExecutor(max_workers=tree.hash_jobs) as executor:
                 tasks = executor.map(worker, file_infos)
                 hashes = dict(zip(file_infos, tasks))
         return hashes
@@ -412,7 +424,7 @@ class BaseRemoteTree:
 
         name = name or from_info.name
 
-        self._upload(
+        self._upload(  # noqa, pylint: disable=no-member
             from_info.fspath,
             to_info,
             name=name,
@@ -503,7 +515,7 @@ class BaseRemoteTree:
 
         tmp_file = tmp_fname(to_info)
 
-        self._download(
+        self._download(  # noqa, pylint: disable=no-member
             from_info, tmp_file, name=name, no_progress_bar=no_progress_bar
         )
 
@@ -515,14 +527,16 @@ class BaseRemoteTree:
                 path_info = self.path_info / prefix[:2] / prefix[2:]
             else:
                 path_info = self.path_info / prefix[:2]
+            prefix = True
         else:
             path_info = self.path_info
+            prefix = False
         if progress_callback:
-            for file_info in self.walk_files(path_info):
+            for file_info in self.walk_files(path_info, prefix=prefix):
                 progress_callback()
                 yield file_info.path
         else:
-            yield from self.walk_files(path_info)
+            yield from self.walk_files(path_info, prefix=prefix)
 
     def list_hashes(self, prefix=None, progress_callback=None):
         """Iterate over hashes in this tree.
@@ -865,6 +879,7 @@ class Remote:
             path_info = tree.hash_to_path_info(hash_)
             if tree.is_dir_hash(hash_):
                 # backward compatibility
+                # pylint: disable=protected-access
                 tree._remove_unpacked_dir(hash_)
             tree.remove(path_info)
             removed = True
