@@ -12,7 +12,13 @@ def push(
     all_tags=False,
     recursive=False,
     all_commits=False,
+    run_cache=False,
 ):
+    used_run_cache = self.stage_cache.push(remote) if run_cache else []
+
+    if isinstance(targets, str):
+        targets = [targets]
+
     used = self.used_cache(
         targets,
         all_branches=all_branches,
@@ -23,5 +29,7 @@ def push(
         remote=remote,
         jobs=jobs,
         recursive=recursive,
+        used_run_cache=used_run_cache,
     )
-    return self.cloud.push(used, jobs, remote=remote)
+
+    return len(used_run_cache) + self.cloud.push(used, jobs, remote=remote)
